@@ -95,14 +95,12 @@ Example JSON Element:
         "neutron"
     ],
     "driver_info": {
-      "power": {
-        "ipmi_target_channel": "0",
-        "ipmi_username": "ADMIN",
-        "ipmi_address": "192.168.122.1",
-        "ipmi_target_address": "0",
-        "ipmi_password": "undefined",
-        "ipmi_bridging": "single"
-      }
+      "ipmi_target_channel": "0",
+      "ipmi_username": "ADMIN",
+      "ipmi_address": "192.168.122.1",
+      "ipmi_target_address": "0",
+      "ipmi_password": "undefined",
+      "ipmi_bridging": "single"
     },
     "nics": [
       {
@@ -318,11 +316,6 @@ def main():
         if len(groups[group]['hosts']) == 0:
             del groups[group]
 
-    # FIXME(dtantsur): there is a conflict between the Bifrost's and the node's
-    # network_interface. Drop the node's one for now.
-    for host, items in hostvars.items():
-        items.pop('network_interface', None)
-
     # General Data Conversion
 
     inventory = {'_meta': {'hostvars': hostvars}}
