@@ -71,20 +71,23 @@ mkdir -p ${LOG_LOCATION}/all
 sudo cp -a /var/log/* ${LOG_LOCATION}/all/.
 sudo chown -R $USER ${LOG_LOCATION}/all
 
+sudo systemctl > ${LOG_LOCATION}/all-services.txt
 sudo journalctl -u libvirtd &> ${LOG_LOCATION}/libvirtd.log
-sudo journalctl -u ironic-api &> ${LOG_LOCATION}/ironic-api.log
-sudo journalctl -u ironic-conductor &> ${LOG_LOCATION}/ironic-conductor.log
+sudo journalctl -u ironic &> ${LOG_LOCATION}/ironic.log
 sudo journalctl -u ironic-inspector &> ${LOG_LOCATION}/ironic-inspector.log
 sudo journalctl -u dnsmasq &> ${LOG_LOCATION}/dnsmasq.log
 sudo journalctl -u vbmcd &> ${LOG_LOCATION}/vbmcd.log
 sudo journalctl -u redfish-emulator &> ${LOG_LOCATION}/redfish-emulator.log
 sudo journalctl -u uwsgi@keystone-public &> ${LOG_LOCATION}/keystone-public.log
-sudo journalctl -u uwsgi@keystone-admin &> ${LOG_LOCATION}/keystone-admin.log
 
 # Copy PXE information
 mkdir -p ${LOG_LOCATION}/pxe/
-cp /httpboot/ipxe.* ${LOG_LOCATION}/pxe/
-cp -aL /httpboot/pxelinux.cfg/ ${LOG_LOCATION}/pxe/
+sudo ls -lR /var/lib/ironic/httpboot > ${LOG_LOCATION}/pxe/listing.txt
+sudo bash -c "cp -aL /var/lib/ironic/httpboot/*.ipxe ${LOG_LOCATION}/pxe/"
+sudo cp -aL /var/lib/ironic/httpboot/pxelinux.cfg/ ${LOG_LOCATION}/pxe/
+
+# Copy files generated by bifrost-cli
+cp -a ${SCRIPT_HOME}/../playbooks/*.json ${LOG_LOCATION}
 
 # Copy baremetal information
 source $HOME/openrc bifrost
