@@ -5,7 +5,6 @@ set -euxo pipefail
 export PYTHONUNBUFFERED=1
 SCRIPT_HOME="$(cd "$(dirname "$0")" && pwd)"
 BIFROST_HOME=$SCRIPT_HOME/..
-ANSIBLE_INSTALL_ROOT=${ANSIBLE_INSTALL_ROOT:-/opt/stack}
 USE_DHCP="${USE_DHCP:-false}"
 BUILD_IMAGE="${BUILD_IMAGE:-false}"
 BAREMETAL_DATA_FILE=${BAREMETAL_DATA_FILE:-'/tmp/baremetal.json'}
@@ -98,16 +97,6 @@ elif [ ${BUILD_IMAGE} = "true" ]; then
     DOWNLOAD_IPA=false
     CREATE_IPA_IMAGE=true
 
-    # if running in OpenStack CI, then make sure epel is enabled
-    # since it may already be present (but disabled) on the host
-    # we need epel for debootstrap
-    if env | grep -q ^ZUUL; then
-        if [[ "$OS_DISTRO" == "rhel" ]] || [[ "$OS_DISTRO" == "centos" ]]; then
-            sudo dnf install -y dnf-utils
-            sudo dnf install -y epel-release || true
-            sudo dnf config-manager --set-enabled epel || true
-        fi
-    fi
 elif [ ${ENABLE_KEYSTONE} = "true" ]; then
     NOAUTH_MODE=false
     CLOUD_CONFIG+=" -e cloud_name=bifrost"
@@ -195,6 +184,7 @@ ${ANSIBLE} -vvvv \
     -i inventory/target \
     ${TEST_PLAYBOOK} \
     -e use_cirros=${USE_CIRROS} \
+    -e use_tinyipa=true \
     -e testing_user=${TESTING_USER} \
     -e test_vm_num_nodes=${TEST_VM_NUM_NODES} \
     -e inventory_dhcp=${INVENTORY_DHCP} \
